
/*  (1) create Groups   */
CREATE TABLE IF NOT EXISTS `{MPREFIX}TE_Groups` (
  `idGroups` INT NOT NULL AUTO_INCREMENT ,
  `Name` VARCHAR(500) NOT NULL COMMENT 'name of group' ,
  `ImageUrl` VARCHAR(1000) NULL ,
  `Description` TEXT NULL COMMENT 'pure html description. can contain any sort of data.' ,
  `MaxMembers` INT NOT NULL DEFAULT 0 COMMENT 'max members can be in this group' ,
  `MyOrder` INT NULL ,
  PRIMARY KEY (`idGroups`) ,
  UNIQUE INDEX `idGroups_UNIQUE` (`idGroups` ASC) )
  ENGINE = MyISAM
  DEFAULT CHARACTER SET = utf8;
  
/* (2) create Ranks */
CREATE TABLE IF NOT EXISTS `{MPREFIX}TE_Ranks` (
  `idRanks` INT NOT NULL AUTO_INCREMENT ,
  `ImageUrl` VARCHAR(1000) NULL COMMENT 'image url used to show rank image' ,
  `Name` VARCHAR(800) NOT NULL COMMENT 'name of rank' ,
  `Description` TEXT NULL ,
  `MyOrder` INT NOT NULL DEFAULT 1 COMMENT 'list order to show' ,
  PRIMARY KEY (`idRanks`) ,
  UNIQUE INDEX `idRanks_UNIQUE` (`idRanks` ASC) )
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COMMENT = 'Ranks';

/* (3) create Awards    */ 
CREATE TABLE IF NOT EXISTS `{MPREFIX}TE_Awards` (
  `idAwards` INT NOT NULL AUTO_INCREMENT ,
  `ImageUrl` VARCHAR(1000) NULL COMMENT 'image url used to show award image' ,
  `Name` VARCHAR(800) NOT NULL COMMENT 'name of award' ,
  `Description` TEXT NULL ,
  `MyOrder` INT NOT NULL DEFAULT 1 COMMENT 'list order to show' ,
  PRIMARY KEY (`idAwards`) ,
  UNIQUE INDEX `idAwards_UNIQUE` (`idAwards` ASC) )
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COMMENT = 'Awards';

/* (4) create Locations */ 
CREATE TABLE IF NOT EXISTS `{MPREFIX}TE_Locations` (
  `idLocations` INT NOT NULL AUTO_INCREMENT ,
  `Name` VARCHAR(100) NOT NULL ,
  `ImageUrl` VARCHAR(1000) NULL ,
  PRIMARY KEY (`idLocations`) ,
  UNIQUE INDEX `idLocations_UNIQUE` (`idLocations` ASC) )
  ENGINE = MyISAM
  DEFAULT CHARACTER SET = utf8;

/* (5) create Members   */
CREATE TABLE IF NOT EXISTS `{MPREFIX}TE_Members` (
  `idMembers` INT NOT NULL AUTO_INCREMENT ,
  `Name` VARCHAR(100) NOT NULL COMMENT 'member name' ,
  `Role` VARCHAR(200) NULL COMMENT 'member role',
  `ImageUrl` VARCHAR(1000) NULL COMMENT 'members profile image url' ,
  `RankID` INT NULL ,
  `Status` ENUM('Negotiation', 'Declined', 'Active', 'Vacation', 'Suspended', 'Retired', 'Fired') NULL ,
  `LocationID` INT NULL ,
  `ProfileInfo` TEXT NULL ,
  `MemberJoinDate` DATETIME NULL ,
  `MemberRankDate` DATETIME NULL ,
  `GroupID` INT NULL ,
  UNIQUE INDEX `idMembers_UNIQUE` (`idMembers` ASC) ,
  UNIQUE INDEX `Name_UNIQUE` (`Name` ASC) )
  ENGINE = MyISAM
  DEFAULT CHARACTER SET = utf8
  COMMENT = 'list of members';

/* (6) create AwardsList    */ 
CREATE TABLE IF NOT EXISTS `{MPREFIX}TE_AwardsList` (
  `idAwardsList` INT NOT NULL AUTO_INCREMENT ,
  `AwardID` INT NOT NULL COMMENT 'award id in Awards table' ,
  `MemberID` INT NOT NULL COMMENT 'id of member in Member table' ,
  `GivenDate` DATETIME NOT NULL COMMENT 'date when member got that award' ,
  PRIMARY KEY (`idAwardsList`) ,
  UNIQUE INDEX `idAwardsList_UNIQUE` (`idAwardsList` ASC) )
  ENGINE = MyISAM
  DEFAULT CHARACTER SET = utf8
  COMMENT = 'contains awards list of all members to make possible hall of it';